/**
 * @fileoverview Footer component for the tattoo studio website.
 * Provides studio information, navigation links, contact details, hours, and social media links.
 */

import React from 'react'
import { Link } from 'react-router-dom'

/**
 * Footer component containing studio information, navigation, contact details, and social links
 * @returns {JSX.Element} The footer component
 */
function Footer() {
  // Get current year for copyright notice
  const currentYear = new Date().getFullYear()
  
  // Social media links configuration
  const socialLinks = [
    {
      name: 'Instagram',
      url: 'https://instagram.com/studioname',
      icon: (
        <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 24 24" aria-hidden="true">
          <path fillRule="evenodd" d="M12.017 0C5.396 0 .029 5.367.029 11.987c0 6.62 5.367 11.987 11.988 11.987s11.987-5.367 11.987-11.987C24.004 5.367 18.637.001 12.017.001zM8.449 16.988c-1.297 0-2.448-.49-3.328-1.297C4.243 14.894 3.752 13.743 3.752 12.446s.491-2.448 1.369-3.328c.88-.88 2.031-1.369 3.328-1.369s2.448.489 3.328 1.369c.88.88 1.369 2.031 1.369 3.328s-.489 2.448-1.369 3.328c-.88.807-2.031 1.297-3.328 1.297zm7.718-1.297c-.88.807-2.031 1.297-3.328 1.297s-2.448-.49-3.328-1.297c-.88-.88-1.369-2.031-1.369-3.328s.489-2.448 1.369-3.328c.88-.88 2.031-1.369 3.328-1.369s2.448.489 3.328 1.369c.88.88 1.369 2.031 1.369 3.328s-.489 2.448-1.369 3.328z" clipRule="evenodd" />
        </svg>
      )
    },
    {
      name: 'Facebook',
      url: 'https://facebook.com/studioname',
      icon: (
        <svg className="w-5 h-5" fill="currentColor" viewBox="0 0 24 24" aria-hidden="true">
          <path fillRule="evenodd" d="M22 12c0-5.523-4.477-10-10-10S2 6.477 2 12c0 4.991 3.657 9.128 8.438 9.878v-6.987h-2.54V12h2.54V9.797c0-2.506 1.492-3.89 3.777-3.89 1.094 0 2.238.195 2.238.195v2.46h-1.26c-1.243 0-1.63.771-1.63 1.562V12h2.773l-.443 2.89h-2.33v6.988C18.343 21.128 22 16.991 22 12z" clipRule="evenodd" />
        </svg>
      )
    }
  ]
  
  // Legal links configuration
  const legalLinks = [
    { name: 'Privacy Policy', path: '/privacy' },
    { name: 'Cookie Policy', path: '/cookies' },
    { name: 'Terms of Service', path: '/terms' }
  ]

  return (
    <footer className="bg-black text-white" role="contentinfo">
      <div className="section-padding py-12">
        <div className="container-max">
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
            {/* Studio Info */}
            <div className="space-y-4">
              <h3 className="text-xl font-serif font-semibold">Ink With Intention Studio</h3>
              <p className="text-gray-300 text-sm leading-relaxed">
                High-end tattoo studio creating custom artwork with precision and artistry. Where every line tells your story.
              </p>
              <div className="text-sm text-gray-400">
                <p><span className="font-medium">Licensed Studio</span> #INK2024</p>
                <p><span className="font-medium">Health Department</span> Certified</p>
              </div>
            </div>

            {/* Quick Links */}
            <div className="space-y-4">
              <h3 className="text-lg font-serif font-semibold">Quick Links</h3>
              <nav className="space-y-2" aria-label="Footer navigation">
                <Link to="/portfolio" className="block text-gray-300 hover:text-accent transition-colors duration-300 text-sm">
                  Portfolio
                </Link>
                <Link to="/artists" className="block text-gray-300 hover:text-accent transition-colors duration-300 text-sm">
                  Artists
                </Link>
                <Link to="/booking" className="block text-gray-300 hover:text-accent transition-colors duration-300 text-sm">
                  Book Consultation
                </Link>
                <Link to="/aftercare" className="block text-gray-300 hover:text-accent transition-colors duration-300 text-sm">
                  Aftercare Guide
                </Link>
              </nav>
            </div>

            {/* Contact Info */}
            <div className="space-y-4">
              <h3 className="text-lg font-serif font-semibold">Contact</h3>
              <div className="space-y-2 text-sm text-gray-300">
                <p>123 Art Street</p>
                <p>Creative District, CD 12345</p>
                <p className="pt-2">
                  <a href="tel:+1234567890" className="hover:text-accent transition-colors duration-300">
                    (123) 456-7890
                  </a>
                </p>
                <p>
                  <a href="mailto:info@studioname.com" className="hover:text-accent transition-colors duration-300">
                    info@studioname.com
                  </a>
                </p>
              </div>
            </div>

            {/* Hours & Social */}
            <div className="space-y-4">
              <h3 className="text-lg font-serif font-semibold">Hours</h3>
              <dl className="space-y-1 text-sm text-gray-300">
                <div className="flex justify-between">
                  <dt className="font-medium">Monday - Friday:</dt>
                  <dd>12pm - 8pm</dd>
                </div>
                <div className="flex justify-between">
                  <dt className="font-medium">Saturday:</dt>
                  <dd>10am - 6pm</dd>
                </div>
                <div className="flex justify-between">
                  <dt className="font-medium">Sunday:</dt>
                  <dd>Closed</dd>
                </div>
              </dl>
              <div className="pt-4">
                <h4 className="text-sm font-semibold mb-2">Follow Us</h4>
                <div className="flex space-x-4">
                  {socialLinks.map((social, index) => (
                    <a 
                      key={index}
                      href={social.url} 
                      target="_blank" 
                      rel="noopener noreferrer"
                      className="text-gray-300 hover:text-accent transition-colors duration-300"
                      aria-label={`Follow us on ${social.name}`}
                    >
                      {social.icon}
                    </a>
                  ))}
                </div>
              </div>
            </div>
          </div>

          {/* Bottom Bar */}
          <div className="border-t border-gray-800 mt-12 pt-8">
            <div className="flex flex-col md:flex-row justify-between items-center space-y-4 md:space-y-0">
              <div className="text-sm text-gray-400">
                <p>&copy; {currentYear} Ink With Intention Studio. All rights reserved.</p>
              </div>
              <nav aria-label="Legal links" className="flex space-x-6 text-sm text-gray-400">
                {legalLinks.map((link, index) => (
                  <Link 
                    key={index}
                    to={link.path} 
                    className="hover:text-accent transition-colors duration-300"
                  >
                    {link.name}
                  </Link>
                ))}
              </nav>
            </div>
          </div>
        </div>
      </div>
    </footer>
  )
}

export default Footer